#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Taz library: Storage Account
"""
import re
from azure.storage.blob import BlobServiceClient
from azure.cosmosdb.table.tableservice import TableService


class StorageAccount:
    def __init__(self, name=None, connection_string=None, key=None):
        """Storage Class

        connection_string or key + name are required

        :param name: storage account name
        :type name: str, optionnal
        :param connection_string: storage account connection string
        :type connection_string: str, optionnal
        :param key: key, defaults to None
        :type key: str, optional
        """
        self.name = name
        self.key = key
        self.connection_string = connection_string

        if self.name is None:
            self.name = re.search(";AccountName=(.*?);", self.connection_string)

        if self.connection_string is None:
            self.connection_string = "DefaultEndpointsProtocol=https;AccountName={};AccountKey={};EndpointSuffix=core.windows.net".format(
                self.name, self.key
            )

        self.blob_service_client = BlobServiceClient.from_connection_string(
            self.connection_string
        )

        self.table_service_client = TableService(
            connection_string=self.connection_string
        )

    def list_tables(self):
        """list storage account tables

        :return: list of tables
        :rtype: azure.cosmosdb.table.common.models.ListGenerator
        """
        return self.table_service_client.list_tables()

    def list_containers(self, prefix=None):
        """list storage account containers

        :param prefix: prefix of containers to include in selection, defaults to None
        :type prefix: str, optional
        :return: list of container
        :rtype: Iterator of azure.storage.blob.models.Container
        """
        return self.blob_service_client.list_containers(name_starts_with=prefix)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Taz library: Container Registry operations
"""

from azure.common.client_factory import get_client_from_cli_profile
from azure.mgmt.containerregistry import ContainerRegistryManagementClient
from msrestazure.azure_active_directory import MSIAuthentication
from azure.mgmt.containerinstance.models import ImageRegistryCredential

from azure.common.credentials import ServicePrincipalCredentials
import os


class ContainerRegistry:

    """Summary
    
    Attributes:
        - client (TYPE): Description
        - credentials (TYPE): Description
        - name (TYPE): Description
        - resource_group (TYPE): Description
    """

    def __init__(self, resource_group, name, subscription_id=None):

        self.tenant_id = os.environ.get("AZURE_TENANT_ID")
        self.client_id = os.environ.get("AZURE_CLIENT_ID")
        self.cli_user = os.environ.get("AZURE_CLI_USER")
        if subscription_id:
            self.subscription_id = subscription_id
        else:
            self.subscription_id = os.environ.get("AZURE_SUBSCRIPTION_ID")

        if os.environ.get("AZURE_CLIENT_SECRET"):
            self.client = ContainerRegistryManagementClient(
                ServicePrincipalCredentials(
                    client_id=os.environ.get("AZURE_CLIENT_ID"),
                    secret=os.environ.get("AZURE_CLIENT_SECRET"),
                    tenant=os.environ.get("AZURE_TENANT_ID"),
                ),
                self.subscription_id,
            )
            self.mode = "service_principal"
        elif self.cli_user:
            print("cli profile")
            self.mode = "cli_profile"
            self.client = get_client_from_cli_profile(
                ContainerRegistryManagementClient, subscription_id=self.subscription_id
            )
        else:
            self.mode = "managed_identity"
            self.client = ContainerRegistryManagementClient(
                MSIAuthentication(), self.subscription_id
            )

        self.name = name
        self.resource_group = resource_group
        self.credentials = self.client.registries.list_credentials(resource_group, name)

    def get_credentials(self):
        return ImageRegistryCredential(
            server="{0}.azurecr.io".format(self.name),
            username=self.credentials.username,
            password=self.credentials.passwords[0].value,
        )


class ContainerImage:

    """Summary

    Attributes:
        container_registry (TYPE): Description
        name (TYPE): Description
    """

    def __init__(self, name, container_registry):

        self.container_registry = container_registry
        self.name = name

    def get_name(self):
        return self.name



#!/usr/bin/env python

import sys

sys.path.insert(0, "../")

from tests.config import *

dicts_name = ["keyvault", "auth", "blob", "acr", "aci", "dls", "dls_glob", "tables"]
safe_values = ["client_secret", "storage_connection_string", "storage_key", "sas_key"]


def displaydict(dict_name):
    dict = eval(dict_name)
    print("\n{} = {}".format(dict_name, "{"))
    for key, value in dict.items():
        if key in safe_values:
            value = "<secured string>"
        print(f'    {key}: "{value}"')
    print("}")


for dict_name in dicts_name:
    displaydict(dict_name)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest
from tests.config import *


class ConfigTests(unittest.TestCase):
    def setUp(self):
        self.template_file = "config_template.py"
        self.dicts = ["keyvault", "auth", "blob", "acr", "aci", "dls", "dls_glob"]

    def test_010_mktemplate(self):
        self.fd = open(self.template_file, "w")
        for dict in self.dicts:
            self.fd.write(f"{dict} = " + "{\n")
            for key in globals()[dict]:
                self.fd.write(f'    "{key}": "xxxxxxxxx"\n')
            self.fd.write("}\n")
        self.fd.close()


if __name__ == "__main__":
    sys.argv.append("-v")
    unittest.main()



keyvault = {
    "name": "kvdvldev",
    "secret_name": "REGISTRY-PASSWORD",
    "tenant_id": "4a7c8238-5799-4b16-9fc6-9ad8fce5a7d9",
    "client_id": "9d6f83f7-af2f-4a8d-b692-e2329dbbef9d",
    "client_secret": "C89nigG4BeonI",
}

auth = {
    "resource_group": "RG-APPLI-RED-DEV",
    "managed_identity": "mi-aci-wag-dev-01",
    "subscription_id": "5f82da32-5cad-49a4-aec5-5ba8806e6d9c",
    "tenant_id": "4a7c8238-5799-4b16-9fc6-9ad8fce5a7d9",
    "client_id": "1300f1b6-1bc2-4658-a504-86a1850805d2",
    "client_secret": "E.ZmS5LjjYpqjsb38=DgAn5WtIibBd.@",
}

blob = {
    "storage_account_name": "zstalrsdvllogdev01",
    "storage_key": "z++1cFPTnrNBNIM6QONcnjYUXa1VZuCs6DpsP+x9ELEuItoAZyM/W+FQLqlxsy/DWfjxywsJu5FjW2O7Wc3P1A==",
    "storage_connection_string": "DefaultEndpointsProtocol=https;AccountName=zstalrsdvllogdev01;AccountKey=z++1cFPTnrNBNIM6QONcnjYUXa1VZuCs6DpsP+x9ELEuItoAZyM/W+FQLqlxsy/DWfjxywsJu5FjW2O7Wc3P1A==;EndpointSuffix=core.windows.net",
    "sas_key": "?sv=2019-10-10&ss=bfqt&srt=sco&sp=rwdlacupx&se=2021-05-05T23:11:11Z&st=2020-05-05T15:11:11Z&spr=https&sig=LwTi%2BFlw4kLJWYip8oINKHOnwkNMZOE3HbYVrcQ32qg%3D",
    "sas_url": "https://zstalrsdvllogdev01.blob.core.windows.net/?sv=2019-10-10&ss=bfqt&srt=sco&sp=rwdlacupx&se=2021-05-05T23:11:11Z&st=2020-05-05T15:11:11Z&spr=https&sig=LwTi%2BFlw4kLJWYip8oINKHOnwkNMZOE3HbYVrcQ32qg%3D",
    "container_name": "unittest-taz",
    "path": "test.csv",
    "sas_url_path": "test_sas_url.csv",
    "sas_key_path": "test_sas_key.csv",
    "localpath": "/tmp/test.csv",
    "gzip_path": "test.csv.gz",
    "data": "col1,col2,col3\nval11,val12,val13\nval21,val22,val23",
}

tables = {
    "storage_account_name": "zstalrsdvllogdev01",
    "storage_key": "z++1cFPTnrNBNIM6QONcnjYUXa1VZuCs6DpsP+x9ELEuItoAZyM/W+FQLqlxsy/DWfjxywsJu5FjW2O7Wc3P1A==",
    "storage_connection_string": "DefaultEndpointsProtocol=https;AccountName=zstalrsdvllogdev01;AccountKey=z++1cFPTnrNBNIM6QONcnjYUXa1VZuCs6DpsP+x9ELEuItoAZyM/W+FQLqlxsy/DWfjxywsJu5FjW2O7Wc3P1A==;EndpointSuffix=core.windows.net",
    "sas_key": "?sv=2019-10-10&ss=bfqt&srt=sco&sp=rwdlacupx&se=2021-05-05T23:11:11Z&st=2020-05-05T15:11:11Z&spr=https&sig=LwTi%2BFlw4kLJWYip8oINKHOnwkNMZOE3HbYVrcQ32qg%3D",
    "sas_url": "https://zstalrsdvllogdev01.blob.core.windows.net/?sv=2019-10-10&ss=bfqt&srt=sco&sp=rwdlacupx&se=2021-05-05T23:11:11Z&st=2020-05-05T15:11:11Z&spr=https&sig=LwTi%2BFlw4kLJWYip8oINKHOnwkNMZOE3HbYVrcQ32qg%3D",
    "table_name": "taztest",
}

acr = {
    "resource_group": "RG-APPLI-RED-DEV",
    "registry_name": "crreddev",
    "subscription_id": "5f82da32-5cad-49a4-aec5-5ba8806e6d9c",
    "image_name": "hello-world",
}

aci = {
    "resource_group": "RG-APPLI-RED-DEV",
    "container_group_name": "cg-taz-test-unit",
    "location": "northeurope",
    "subscription_id": "5f82da32-5cad-49a4-aec5-5ba8806e6d9c",
    "logs_sas_key": "?sv=2019-02-02&ss=bfqt&srt=sco&sp=rwdlacup&se=2021-04-05T02:04:07Z&st=2020-04-04T18:04:07Z&spr=https&sig=gcK6vxvENtBnXfCfVj7nPxdSsQYcY4rS4W740fTKA80%3D",
    "logs_container": "unittest-taz",
    "logs_storage_account": "zstalrsdvllogdev01",
}

dls = {
    "dls_name": "lemanhprod",
    "tenant_id": "4a7c8238-5799-4b16-9fc6-9ad8fce5a7d9",
    "client_id": "e3952129-496b-416b-a244-67c43bd5bddd",
    "client_secret": "/KauQDlt2yiL34n9xsCxPLJMgKVzf.==",
    # "https_proxy": "host.docker.internal:3128",
    "https_proxy": "localhost:3128",
    "path": "SNCF/landing/input/METEOFRANCE/data_files/OBSERVATIONS_5MN/2019",
    "glob_path": "SNCF/landing/input/METEOFRANCE/data_files/OBSERVATIONS_5MN/2019/matriceSNCF_20191212*",
    "file_name": "matriceSNCF_201905201520.csv",
    "gz_file_name": "SNCF/landing/input/METEOFRANCE/data_files/PREVISIONS/20190123/previsions_20190123_J1.csv.gz",
    "tmp_file_name": "/tmp/taz.tmp",
}

dls_glob = {}



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Taz library: Azure Tables (Cosmos DB light)
"""

import datetime as datetime
import json
import pandas as pd

from azure.cosmosdb.table.models import Entity
from azure.cosmosdb.table.tablebatch import TableBatch as AzureTableBatch

from taz.storage_account import StorageAccount

from taz.exception import (
    TableBatchExceedCapacityException,
    TableBatchDeleteForbiddenException,
    TableBatchDataframeTooLargeException,
)


class Table:
    def __init__(self, table_name: str, storage_account: StorageAccount):
        """Table class

        :param table_name: name of table
        :type table_name: str
        :param storage_account: [description]
        :type storage_account: StorageAccount
        """
        self.name = table_name
        self.storage_account = storage_account

    def create(self):
        """create table
        do nothing if already exists

        :return: self obj
        :rtype: taz.table.Table
        """
        if not self.exists():
            self.storage_account.table_service_client.create_table(self.name)
        return self

    def exists(self):
        """test existance of table

        :return: Existance of table
        :rtype: bool
        """
        return self.storage_account.table_service_client.exists(self.name)

    def delete(self):
        """delete table

        :return: self obj
        :rtype: taz.table.Table
        """
        self.storage_account.table_service_client.delete_table(self.name)
        return self

    def insert_entity(self, entity: dict):
        """insert entity

        :param entity: entity to insert (must content a PartitionKey and a RowKey)
        :type entity: dict
        :return: return self object
        :rtype: taz.table.Table
        """
        self.storage_account.table_service_client.insert_entity(self.name, entity)
        return self

    def upsert_entity(self, entity: dict):
        """insert or replace entity

        :param entity: entity to upsert (must content a PartitionKey and a RowKey)
        :type entity: dict
        :return: return self object
        :rtype: taz.table.Table
        """
        self.storage_account.table_service_client.insert_or_replace_entity(
            self.name, entity
        )
        return self

    def query_entities_to_dataframe(self, filter=None):
        """query entities to pandas Dataframe

        ODATA queries documentation:
        https://docs.microsoft.com/en-us/rest/api/storageservices/querying-tables-and-entities

        Example:
        "PartitionKey eq 'users' and RowKey gt 'Fauchard-' and RowKey lt 'Fauchard-z'"

        :param filter: odata request filter, defaults to None
        :type filter: str, optional
        :return: pandas dataframe
        :rtype: pd.Dataframe
        """
        return pd.DataFrame(self.query_entities(filter=filter))

    def query_entities(self, filter=None):
        """query entities

        ODATA queries documentation:
        https://docs.microsoft.com/en-us/rest/api/storageservices/querying-tables-and-entities

        Example:
        "PartitionKey eq 'users' and RowKey gt 'Fauchard-' and RowKey lt 'Fauchard-z'"

        :param filter: odata request filter, defaults to None
        :type filter: str, optional
        :return: entities
        :rtype: dict[]
        """
        return self.storage_account.table_service_client.query_entities(
            self.name, filter=filter,
        )

    def merge_entity(self, entity: dict):
        """insert or replace entity

        :param entity: entity to upsert (must content a PartitionKey and a RowKey)
        :type entity: dict
        :return: return self object
        :rtype: taz.table.Table
        """
        self.storage_account.table_service_client.merge_entity(self.name, entity)
        return self

    def delete_entity(self, partition_key: str, row_key: str):
        """delete entity by partition and row keys

        :param partition_key: partition key
        :type partition_key: str
        :param row_key: row key
        :type row_key: str
        :return: return self object
        :rtype: taz.table.Table
        """
        self.storage_account.table_service_client.delete_entity(
            self.name, partition_key=partition_key, row_key=row_key
        )
        return self

    def get_entity(self, partition_key: str, row_key: str):
        """get entity by partition and row keys

        :param partition_key: partition key
        :type partition_key: str
        :param row_key: row key
        :type row_key: str
        :return: selected entity
        :rtype: azure.storage.table.models.Entity (can be used as a dict)
        """
        return self.storage_account.table_service_client.get_entity(
            self.name, partition_key=partition_key, row_key=row_key
        )

    def __str__(self):
        return self.name


class TableBatch(Table):
    def __init__(
        self,
        table_name: str,
        storage_account: StorageAccount,
        max_tasks=100,
        auto_commit=False,
    ):
        """Batch Table Class

        Can write up to max_tasks entities (update or insert) 
        with a single request

        :param table_name: table to handle
        :type table_name: str
        :param storage_account: storage account
        :type storage_account: StorageAccount
        :param max_tasks: max tasks to handle, defaults to 100, max 100
        :type max_tasks: int, optional
        :param auto_commit: auto commit or not, defaults to False
        :type auto_commit: bool, optional
        """
        Table.__init__(self, table_name, storage_account)
        if max_tasks > 100:
            self.max_tasks = 100
        else:
            self.max_tasks = max_tasks
        self.auto_commit = auto_commit
        self.sessions = {}
        self._start_session()

    def _start_session(self):
        self.session_id = datetime.datetime.utcnow().isoformat()
        self.sessions[self.session_id] = {
            "state": "pending",
            "mode": "",
            "results": [],
            "submitted_tasks": [],
            "size": 0,
        }
        self.tasks_to_commit = 0
        self.batch = AzureTableBatch()

    def _add_task(self, type: str, partition_key: str, row_key: str):
        self.sessions[self.session_id]["submitted_tasks"].append(
            {"Type": type, "PartitionKey": partition_key, "RowKey": row_key}
        )
        return self

    def delete(self):
        raise TableBatchDeleteForbiddenException(self.storage_account.name, self.name)

    def commit_batch(self):
        """commit batch task

        :return: self
        :rtype: taz.table.BatchTable
        """
        self.sessions[self.session_id]["mode"] = "manual"
        self._commit_batch()
        return self

    def _commit_batch(self):
        if self.tasks_to_commit > 0:
            response = self.storage_account.table_service_client.commit_batch(
                self.name, self.batch
            )
            self.sessions[self.session_id]["size"] = self.tasks_to_commit
            self.sessions[self.session_id]["results"] = response
            self.sessions[self.session_id]["state"] = "committed"
            self._start_session()
        return self

    def _auto_commit(self):
        """private method to handle auto batch commit

        :raises TableBatchExceedCapacityException: if batch exceed capacity
        :return: self
        :rtype: TableBatch
        """
        if self.tasks_to_commit >= self.max_tasks:
            if self.auto_commit:
                self.sessions[self.session_id]["mode"] = "auto"
                self._commit_batch()
            else:
                raise TableBatchExceedCapacityException(
                    self.storage_account.name, self.name
                )
        self.tasks_to_commit += 1
        return self

    def insert_or_replace_entity(self, entity: dict):
        """replace entity is exists insert otherwise

        :param entity: entity to insert or replace
        (must include PartitionKey and RowKey)
        :type entity: dict
        :return: self
        :rtype: TableBatch
        """
        self._auto_commit()._add_task(
            "insert_or_replace", entity["PartitionKey"], entity["RowKey"]
        ).batch.insert_or_replace_entity(entity)

        return self

    def _check_dataframe_size(self, df: pd.DataFrame):
        if (
            df.shape[0] > (self.max_tasks - self.tasks_to_commit)
        ) and not self.auto_commit:
            raise TableBatchDataframeTooLargeException(df.shape[0])
        return self

    def insert_or_replace_entities_from_dataframe(self, df: pd.DataFrame):
        """batch insert or replace entities from dataframe

        :param df: pandas dataframe
        must include PartitionKey and RowKey column
        :type df: pd.DataFrame
        :return: self
        :rtype: TableBatch
        """
        self._check_dataframe_size(df)
        for entity in df.to_dict("records"):
            self.insert_or_replace_entity(entity)
        return self

    def merge_entities_from_dataframe(self, df: pd.DataFrame, if_match="*"):
        """batch merge entities from dataframe

        :param df: pandas dataframe
        must include PartitionKey and RowKey column
        :type df: pd.DataFrame
        :param if_match: concurency check 
        etag value or "*" for inconditionnal write, defaults to "*"
        :type if_match: str, optional
        :return: self
        :rtype: TableBatch
        """
        self._check_dataframe_size(df)
        for entity in df.to_dict("records"):
            self.merge_entity(entity, if_match=if_match)
        return self

    def insert_entities_from_dataframe(self, df: pd.DataFrame):
        """batch insert entities from dataframe
        no inserts if one entity exists

        :param df: pandas dataframe
        must include PartitionKey and RowKey column
        :type df: pd.DataFrame
        :return: self
        :rtype: TableBatch
        """
        self._check_dataframe_size(df)
        for entity in df.to_dict("records"):
            self.insert_entity(entity)
        return self

    def merge_entity(self, entity: dict, if_match="*"):
        """merge properties of existing and new entities

        :param entity: entity to merge
        (must include PartitionKey and RowKey)
        :type entity: dict
        :param if_match: concurency check 
        etag value or "*" for inconditionnal write, defaults to "*"
        :type if_match: str, optional
        :return: self
        :rtype: TableBatch
        """
        self._auto_commit()._add_task(
            "merge", entity["PartitionKey"], entity["RowKey"]
        ).batch.merge_entity(entity, if_match=if_match)

        return self

    def insert_entity(self, entity: dict):
        """insert entity
        raise an error if existing

        :param entity: entity to insert
        (must include PartitionKey and RowKey)
        :type entity: dict
        :return: self
        :rtype: TableBatch
        """
        self._auto_commit()._add_task(
            "insert", entity["PartitionKey"], entity["RowKey"]
        ).batch.insert_entity(entity)
        return self

    def delete_entity_from_dataframe(self, df: pd.DataFrame, if_match="*"):
        """batch delete entities from dataframe
        delete nothing if one entity doesn't exists

        :param df: pandas dataframe
        must include PartitionKey and RowKey column
        :type df: pd.DataFrame
        :param if_match: concurency check 
        etag value or "*" for inconditionnal write, defaults to "*"
        :type if_match: str, optional
        :return: self
        :rtype: TableBatch
        """
        self._check_dataframe_size(df)
        for entity in df.to_dict("records"):
            self.delete_entity(
                entity["PartitionKey"], entity["RowKey"], if_match=if_match
            )
        return self

    def delete_entity(self, partition_key: str, row_key: str, if_match="*"):
        """delete entity
        raise an error if not existing

        :param partition_key: value of PartitionKey property
        :type partition_key: str
        :param row_key: value of RowKey property
        :type row_key: str
        :param if_match: concurency check 
        etag value or "*" for inconditionnal write, defaults to "*"
        :type if_match: str, optional
        :return: self
        :rtype: TableBatch
        """
        self._auto_commit()._add_task(
            "delete", partition_key, row_key
        ).batch.delete_entity(partition_key, row_key, if_match=if_match)
        return self

    def update_entity(self, entity: dict, if_match="*"):
        """pdate entity
        raise an error in not existing

        :param entity: entity to update
        (must include PartitionKey and RowKey)
        :type entity: dict
        :param if_match: concurency check 
        etag value or "*" for inconditionnal write, defaults to "*"
        :type if_match: str, optional
        :return: self
        :rtype: TableBatch
        """
        self._auto_commit()._add_task(
            "update", entity["PartitionKey"], entity["RowKey"]
        ).batch.update_entity(entity, if_match=if_match)
        return self

    def get_stats_as_dataframe(self) -> pd.DataFrame:
        """get batch results as dataframe

        :return: Dataframe with all operations
        :rtype: pd.DataFrame
        """
        return pd.DataFrame(self.get_stats())

    def save_stats(self, table_name=None):
        """save stats in new table (name passed in table_name parameter
        or build from original table name with a suffixe "monitor")

        PartitionKey: "monitor"
        RowKey: SessionId + PartitionKey + RowKey

        :param table_name: [description], defaults to None
        :type table_name: [type], optional
        :return: [description]
        :rtype: [type]
        """
        if table_name is None:
            table_name = self.name + "monitor"
        df = self.get_stats_as_dataframe()
        df["RowKey"] = df["SessionId"] + "-" + df["PartitionKey"] + "-" + df["RowKey"]
        df["PartitionKey"] = "monitor"

        nested_batch = (
            TableBatch(
                table_name, auto_commit=True, storage_account=self.storage_account
            )
            .create()
            .insert_entities_from_dataframe(df)
            .commit_batch()
        )
        return self

    def get_stats(self):
        """results of all batch sessions

        :return: array of dicts with results
        :rtype: dict[]
        """
        entities = []
        for session_id in sorted(self.sessions.keys()):
            for i, task in enumerate(self.sessions[session_id]["submitted_tasks"]):
                entity = {
                    "SessionId": session_id,
                    "Type": task["Type"],
                    "PartitionKey": task["PartitionKey"],
                    "RowKey": task["RowKey"],
                    "CommitMode": self.sessions[session_id]["mode"],
                    "CommitState": self.sessions[session_id]["state"],
                }
                try:
                    entity["Result"] = self.sessions[session_id]["results"][i]
                except IndexError:
                    entity["Result"] = "unavailable"

                entities.append(entity)
        return entities



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest
from taz.aci import SimpleContainerGroup
from taz.acr import ContainerRegistry
from taz.acr import ContainerImage
import tests.config as cfg
import sys


class AciViewTests(unittest.TestCase):
    def setUp(self):

        self.container_group = SimpleContainerGroup(
            cfg.aci["container_group_name"], cfg.aci["resource_group"],
        )
        self.logs_sas_key = cfg.aci["logs_sas_key"]
        self.logs_container = cfg.aci["logs_container"]
        self.logs_storage_account = cfg.aci["logs_storage_account"]

    def test_10_display(self):
        self.assertTrue(self.container_group is not None)
        print(self.container_group)

    def test_15_display_unprotected(self):
        self.assertTrue(self.container_group is not None)
        self.container_group.protected = False
        print(self.container_group)

    def test_20_list_logs(self):
        print(self.container_group.list_logs())

    def test_30_save_logs(self):
        print(
            self.container_group.save_logs(
                self.logs_container,
                sas_key=self.logs_sas_key,
                storage_account_name=self.logs_storage_account,
            )
        )


if __name__ == "__main__":
    sys.argv.append("-v")
    unittest.main()
